==> haskell-test-framework-0.8.1.1-5-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-test-framework.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: test-framework
version: 0.8.1.1
id: test-framework-0.8.1.1-KC8oChssjbiIyg7PdNxvLN
key: test-framework-0.8.1.1-KC8oChssjbiIyg7PdNxvLN
license: BSD3
maintainer: Libraries List <libraries@haskell.org>
homepage: https://batterseapower.github.io/test-framework/
synopsis: Framework for running and organising tests, with HUnit and QuickCheck support
description:
    Allows tests such as QuickCheck properties and HUnit test cases to be assembled into test groups, run in
    parallel (but reported in deterministic order, to aid diff interpretation) and filtered and controlled by
    command line options. All of this comes with colored test output, progress reporting and test statistics output.
category: Testing
author: Max Bolingbroke <batterseapower@hotmail.com>
exposed: True
exposed-modules:
    Test.Framework Test.Framework.Options Test.Framework.Providers.API
    Test.Framework.Runners.Console Test.Framework.Runners.Options
    Test.Framework.Runners.TestPattern Test.Framework.Runners.API
    Test.Framework.Seed
hidden-modules: Test.Framework.Core Test.Framework.Improving
                Test.Framework.Runners.Console.Colors
                Test.Framework.Runners.Console.ProgressBar
                Test.Framework.Runners.Console.Run
                Test.Framework.Runners.Console.Statistics
                Test.Framework.Runners.Console.Table
                Test.Framework.Runners.Console.Utilities
                Test.Framework.Runners.Core Test.Framework.Runners.Processors
                Test.Framework.Runners.Statistics Test.Framework.Runners.ThreadPool
                Test.Framework.Runners.TimedConsumption
                Test.Framework.Runners.XML.JUnitWriter Test.Framework.Runners.XML
                Test.Framework.Utilities
abi: 343073d804e050aff18c62c45ce4d041
trusted: False
import-dirs: /usr/lib/ghc-8.0.1/site-local/test-framework-0.8.1.1
library-dirs: /usr/lib/ghc-8.0.1/site-local/test-framework-0.8.1.1
data-dir: /usr/share/arm-linux-ghc-8.0.1/test-framework-0.8.1.1
hs-libraries: HStest-framework-0.8.1.1-KC8oChssjbiIyg7PdNxvLN
depends:
    ansi-terminal-0.6.2.3-AKTYR0nthhUCHW4HMZvJFX
    ansi-wl-pprint-0.6.7.3-BxXaXM4de7bF6SGXMvMtbC base-4.9.0.0
    containers-0.5.7.1 hostname-1.0-42Ipmmd3lMbCN35rV9k5gh
    old-locale-1.0.0.7-6glXNhHF891B41ZfuI8hU8
    random-1.1-54KmMHXjttlERYcr1mvsAe
    regex-posix-0.95.2-Fy6xYMm8dnjHHt23b8RdmR time-1.6.0.1
    xml-1.3.14-rYbwgRBahsKh5Xn1LyTeP
haddock-interfaces: /usr/share/doc/haskell-test-framework/html/test-framework.haddock
haddock-html: /usr/share/doc/haskell-test-framework/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-test-framework-0.8.1.1-7-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-test-framework.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: test-framework
version: 0.8.1.1
id: test-framework-0.8.1.1-9XVRGSGBQ623MhuLqYf7vE
key: test-framework-0.8.1.1-9XVRGSGBQ623MhuLqYf7vE
license: BSD3
maintainer: Libraries List <libraries@haskell.org>
homepage: https://batterseapower.github.io/test-framework/
synopsis: Framework for running and organising tests, with HUnit and QuickCheck support
description:
    Allows tests such as QuickCheck properties and HUnit test cases to be assembled into test groups, run in
    parallel (but reported in deterministic order, to aid diff interpretation) and filtered and controlled by
    command line options. All of this comes with colored test output, progress reporting and test statistics output.
category: Testing
author: Max Bolingbroke <batterseapower@hotmail.com>
exposed: True
exposed-modules:
    Test.Framework Test.Framework.Options Test.Framework.Providers.API
    Test.Framework.Runners.Console Test.Framework.Runners.Options
    Test.Framework.Runners.TestPattern Test.Framework.Runners.API
    Test.Framework.Seed
hidden-modules: Test.Framework.Core Test.Framework.Improving
                Test.Framework.Runners.Console.Colors
                Test.Framework.Runners.Console.ProgressBar
                Test.Framework.Runners.Console.Run
                Test.Framework.Runners.Console.Statistics
                Test.Framework.Runners.Console.Table
                Test.Framework.Runners.Console.Utilities
                Test.Framework.Runners.Core Test.Framework.Runners.Processors
                Test.Framework.Runners.Statistics Test.Framework.Runners.ThreadPool
                Test.Framework.Runners.TimedConsumption
                Test.Framework.Runners.XML.JUnitWriter Test.Framework.Runners.XML
                Test.Framework.Utilities
abi: 6264452f383b9abeaeaab0ac93a3953a
trusted: False
import-dirs: /usr/lib/ghc-8.0.1/site-local/test-framework-0.8.1.1
library-dirs: /usr/lib/ghc-8.0.1/site-local/test-framework-0.8.1.1
data-dir: /usr/share/arm-linux-ghc-8.0.1/test-framework-0.8.1.1
hs-libraries: HStest-framework-0.8.1.1-9XVRGSGBQ623MhuLqYf7vE
depends:
    ansi-terminal-0.6.3-EZA1Pyq8DBj2Viel0l4pEB
    ansi-wl-pprint-0.6.7.3-1EvdXA5apxHECzKM1XGqTG base-4.9.0.0
    containers-0.5.7.1 hostname-1.0-42Ipmmd3lMbCN35rV9k5gh
    old-locale-1.0.0.7-6glXNhHF891B41ZfuI8hU8
    random-1.1-54KmMHXjttlERYcr1mvsAe
    regex-posix-0.95.2-Fy6xYMm8dnjHHt23b8RdmR time-1.6.0.1
    xml-1.3.14-9IpHbL0QRqR5eAZpdkwTMQ
haddock-interfaces: /usr/share/doc/haskell-test-framework/html/test-framework.haddock
haddock-html: /usr/share/doc/haskell-test-framework/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
